@echo off
REM
REM BEGIN COPYRIGHT
REM *************************************************************************
REM Licensed Materials - Property of IBM 
REM 5724-L01, 5655-N53, 5724-I82, 5655-R15
REM (C) Copyright IBM Corporation 2010, 2012. All rights reserved. 
REM US Government Users Restricted Rights - Use, duplication, or disclosure
REM restricted by GSA ADP Schedule Contract with IBM Corp.
REM *************************************************************************
REM END COPYRIGHT
REM
REM ----------------------------------------------------------------------------------------------------------------
REM 
REM
REM
REM Description:   Configure DB2 database environment during Migration
REM                This file is for use on Windows systems
REM                This batch file updates databases
REM                Run the script where it is located rather than running it from a different folder
REM Usage: 
REM                dropSchema.bat <dbUserId> <dbPassword>
REM Example:1
REM                dropSchema.bat dbUserId dbPassword
REM ----------------------------------------------------------------------------------------------------------------
setlocal
rem @echo on

SET CUR_DIR=%cd%

%~d0
cd %~p0


if  "%1" == "-h"  	goto PRINT_USAGE
if  "%1" == "-help"  	goto PRINT_USAGE


set DB_USER=%1
set DB_PASSWORD=%2
set DB_NAME=@DB_NAME@

if not "%1" == ""  (
	if not "%2" == ""  (
	 	goto INVOKE_SCRIPT
	) else (
  		goto INPUT_PASSWORD
  	) 
  ) else (
	goto INPUT_USERNAME
) 


:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER="Enter Oracle user[dbUserId]:":
  goto INPUT_USERNAME
)

:INPUT_PASSWORD
if "%DB_PASSWORD%"==""  (
  set /p DB_PASSWORD="Enter Oracle password[dbPassword]:":
  goto INPUT_PASSWORD
)

:INVOKE_SCRIPT
 
set ATSTRING=@

dir /B | findstr "drop*.*sql" > BPM_80.log

for /F "tokens=1* delims=" %%v in ( BPM_80.log) do (
echo %ATSTRING%%%v >> BPM_80.sql
)

echo quit >> BPM_80.sql

rem type BPM_80.sql

call sqlplus %DB_USER%/%DB_PASSWORD%@%DB_NAME% @BPM_80.sql
if not %ERRORLEVEL%==0 (
    echo The dropSchema script has failed. Please check the log for more information.
    goto END
)

if exist BPM_80.sql (
   del BPM_80.sql
)

echo The dropSchema script completed successfully.
goto END

:PRINT_USAGE

echo.
echo ===================================================================================================
echo "Usage: dropSchema.bat  <dbUserName> <dbPassword> "
echo 
echo "Parameters:"
echo "dbUserName        -  User who can execute SQL scripts, for example, db2admin"
echo "dbPassword        -  Password for user who can execute SQL scripts, for example, db2admin. If the password"
echo "                     contains special characters, enclose the password in quotation marks."
echo 
echo "Examples:"
echo "     1.dropSchema.bat -help "
echo "     2.dropSchema.bat [interactive mode] "
echo "     3.dropSchema.bat  WSLE WSLE "
echo 
echo ===================================================================================================

goto END

:END

if exist BPM_80.log (
   del BPM_80.log
)

if exist BPM_80.sql (
   del BPM_80.sql
)

cd /d "%CUR_DIR%"
endlocal
