#!/bin/sh
#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006, 2009, 2012. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

#-----------------------------------------------------------------------------------------------------
# Description:   Configure SQL Server Database environment during Migration
#				 This file is for use on Linux or Unix bash
#                Run the script where it is located rather than running it from a different folder
# Usage: 
#                upgradeSchema.sh <dbUserName> <dbPassword>
#  
# Example:
#                upgradeSchema.sh db2admin db2admin 
#-----------------------------------------------------------------------------------------------------

DB_NAME=@DB_NAME@
DB_USER=$1
DB_PASSWORD=$2

#-----------------------------------------
# Print Message
#-----------------------------------------
print_message() {
echo ===================================================================================================
echo "Usage: upgradeSchema.sh  <dbUserName> <dbPassword>"
echo 
echo "Parameters:"
echo "dbUserName        -  User who can execute sql scripts i.e., db2admin"
echo "dbPassword        -  Password for dbUser who can execute sql scripts i.e., db2admin"
echo 
echo "Examples:"
echo "     1.upgradeSchema.sh -help "
echo "     1.upgradeSchema.sh [interactive mode] "
echo "     2.upgradeSchema.sh  db2admin db2admin "
echo 
echo ===================================================================================================
exit
}

#--------------------------------------------
# Ask user for Database password 
#--------------------------------------------
get_db_password() {
   while true; do
      if [ -n "$DB_PASSWORD" ]; then
         DB_PASSWORD=$DB_PASSWORD
         break
      else
         echo
         echo "Enter Oracle PASSWORD[dbPassword]:"
         read DB_PASSWORD
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for Database user name
#--------------------------------------------
get_db_user() {
   while true; do
      if [ -n "$DB_USER" ]; then
         DB_USER=$DB_USER
         break
      else
         echo
         echo "Enter Oracle user[dbUsername]:"
         read DB_USER
         continue
      fi
   done
}

if ["$1" == ""]; then
    print_message
fi

if [ "$1" == "-h"  -o "$1" == "-help" ] ; then
   print_message
fi


if [ $# == 0 -o $# == 2  ]; then
	DB_USER=$1
	DB_PASSWORD=$2
fi

INIT_DIR=`pwd`

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" == "." ] ; then
   CURRENT_DIR=`pwd`
fi

#  Move to Oracle folder
cd $CURRENT_DIR

#call the following subroutine to get oracle credentials
get_db_user
get_db_password


#Connect to the database specifying the id and the password
rc=0

sqlplus $DB_USER/$DB_PASSWORD@$DB_NAME @upgradeSchema_SchemaStatus.sql

rc=$?

if [ $rc -ne 0 ] ; then
    echo
    echo  "upgradeSchema_SchemaStatus.sql script has failed."
    echo 
    print_message
fi

mv upgradeSchema_SchemaStatus.sql upgradeSchema_SchemaStatus.done

ls *.sql | grep "^upgradeTable" | sed s/^/\@/ > BPM_80.sql

echo quit >> BPM_80.sql

rc=0

sqlplus $DB_USER/$DB_PASSWORD@$DB_NAME @BPM_80.sql

rc=$?

rm -f  BPM_80.sql

if [ $rc -ne 0 ] ; then
    echo
    echo  "upgradeTablespace scripts have failed."
    echo 
fi


rc=0

ls *.sql | grep "^upgradeSchema" | sed s/^/\@/ > BPM_80.sql

echo quit >> BPM_80.sql

sqlplus $DB_USER/$DB_PASSWORD@$DB_NAME @BPM_80.sql

rc=$?

rm -f  BPM_80.sql

if [ $rc -ne 0 ] ; then
    echo
    echo  "upgradeSchema scripts have failed."
    echo 
    print_message
fi

mv upgradeSchema_SchemaStatus.done upgradeSchema_SchemaStatus.sql

cd $INIT_DIR

exit $?

