@echo off
REM
REM BEGIN COPYRIGHT
REM *************************************************************************
REM Licensed Materials - Property of IBM 
REM 5724-L01, 5655-N53, 5724-I82, 5655-R15
REM (C) Copyright IBM Corporation 2010, 2012. All rights reserved. 
REM US Government Users Restricted Rights - Use, duplication, or disclosure
REM restricted by GSA ADP Schedule Contract with IBM Corp.
REM *************************************************************************
REM END COPYRIGHT
REM
REM ----------------------------------------------------------------------------------------------------------------
REM 
REM
REM The SQL Server JDBC driver only supports mixed authentication mode. Therefore,
REM when the SQL Server instance is created, the authentication must be set to
REM "SQL Server and Windows"
REM Make sure OSQL command can be invoked from command line
REM
REM Description:   Configure DB2 database environment during Migration
REM                This file is for use on Windows systems
REM                This batch file updates databases
REM                Run the script where it is located rather than running it from a different folder
REM Usage: 
REM                dropSchema.bat <dbUserId> <dbPassword> <dbHostName>
REM Example:1
REM                dropSchema.bat dbUserId dbPassword localhost
REM ----------------------------------------------------------------------------------------------------------------
setlocal

SET CUR_DIR=%cd%

%~d0
cd %~p0


if  "%1" == "-h"  	goto PRINT_USAGE
if  "%1" == "-help"  	goto PRINT_USAGE


set DB_USER=%1
set DB_PASSWORD=%2
set DB_HOST=%3

if not "%1" == ""  (
	if not "%2" == ""  (
  		if not "%3" == ""  (
		 	goto INVOKE_SCRIPT
		) else (
			goto INPUT_HOSTNAME
		) 
	) else (
  		goto INPUT_PASSWORD
  	) 
  ) else (
	goto INPUT_USERNAME
) 


:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER="Enter SQL Server user[dbUserId]:":
  goto INPUT_USERNAME
)

:INPUT_PASSWORD
if "%DB_PASSWORD%"==""  (
  set /p DB_PASSWORD="Enter SQL Server password[dbPassword]:":
  goto INPUT_PASSWORD
)

:INPUT_HOSTNAME
if "%DB_HOST%"==""  (
  set /p DB_HOST="Enter SQL Server host[dbHostName]:":
  goto INPUT_HOSTNAME
)

:INVOKE_SCRIPT

REM :SERVER
set SERVER_PARAM=-S %DB_HOST%
if "%SERVER%"=="" set SERVER_PARAM=

set CONNECTION_ID=-U %DB_USER% -P %DB_PASSWORD%

REM --  CONNECT TO THE EXISTING DATABSE FOR COMMONDB UPDATES

dir /B | findstr "drop*.*sql" > BPM_80.log

for /F "tokens=1* delims=" %%v in ( BPM_80.log ) do (
    osql -e -b -d @DB_NAME@ %SERVER_PARAM% %CONNECTION_ID% -i%%v -o result.log
    if not %ERRORLEVEL%==0 (
        echo The dropSchema script has failed. Please check the log for more information.
        goto END
    ) 
)

echo The dropSchema script completed successfully.
goto END

:PRINT_USAGE

REM Print usage messages
echo.
echo ======================================================================
echo Usage: dropSchema.bat ^<dbUserId^> ^<dbPassword^> ^<dbHostName^>
echo.
echo Parameters:
echo dbUsername        -  User who can execute common scripts using dbName
echo dbPassword        -  Password for dbuser
echo dbHostName        -  Sql server HostName
echo.
echo Examples:
echo         1. dropSchema.bat -help
echo         1. dropSchema.bat [interactive mode]
echo         2. dropSchema.bat dbUserId dbPassword localhost
echo.             
echo ===========================================================================

goto END

:END

if exist BPM_80.log (
   del BPM_80.log
)
cd /d "%CUR_DIR%"
endlocal
